Publications
============

If you use simsopt in your research, kindly cite simsopt using
reference 1 below.  It is recommended that you also give a reference
for the simsopt release version used in your work. Each release has a
Zenodo archive with a unique DOI. The DOI for the latest release is

   .. image:: https://zenodo.org/badge/247710081.svg
        :target: https://zenodo.org/badge/latestdoi/247710081

Clicking this badge will take you to Zenodo, and on the right of the
page you will find a list of DOIs for previous releases.
   
Here is a list of publications in which simsopt results appear:

.. # The | symbols below are used to put a blank line between each item.

#. | M Landreman, B Medasani, F Wechsung, A Giuliani, R Jorge, and C Zhu,
     "SIMSOPT: A flexible framework for stellarator optimization",
     *J. Open Source Software* **6**, 3525 (2021).
     `[journal version] <https://doi.org/10.21105/joss.03525>`__
   | 

#. | F Wechsung, A Giuliani, M Landreman, A Cerfon, and G Stadler,
     "Single-stage gradient-based stellarator coil design: stochastic optimization",
     *Nuclear Fusion* **62**, 076034 (2022).
     `[journal version] <https://doi.org/10.1088/1741-4326/ac45f3>`__
     `[arXiv version] <https://arxiv.org/pdf/2106.12137>`__
   |
   
#. | M Landreman, B Medasani, and C Zhu,
     "Stellarator optimization for good magnetic surfaces at the same time as quasisymmetry",
     *Phys. Plasmas* **28**, 092505 (2021).
     `[journal version] <https://doi.org/10.1063/5.0061665>`__
     `[arXiv version] <https://arxiv.org/pdf/2106.14930>`__
   |

#. | A Bader, D T Anderson, M Drevlak, B J Faber, C C Hegna, S Henneberg, M Landreman, J C Schmitt, Y Suzuki, and A Ware,
     "Energetic particle transport in optimized stellarators",
     *Nuclear Fusion* **61**, 116060 (2021).
     `[journal version] <https://doi.org/10.1088/1741-4326/ac2991>`__
     `[arXiv version] <https://arxiv.org/pdf/2106.00716>`__
   |
   
#. | M Landreman and E Paul,
     "Magnetic fields with precise quasisymmetry for plasma confinement",
     *Physical Review Letters* **128**, 035001 (2022).
     `[journal version] <https://doi.org/10.1103/PhysRevLett.128.035001>`__
     `[arXiv version] <https://arxiv.org/pdf/2108.03711>`__
   |

#. | F Wechsung and M Landreman and A Giuliani and A Cerfon and G Stadler,
     "Precise stellarator quasi-symmetry can be achieved with electromagnetic coils",
     *Proceedings of the National Academy of Sciences* **119**, e2202084119 (2022).
     `[journal version] <https://doi.org/10.1073/pnas.2202084119>`__
   |

#. | A Baillod, J Loizu, J P Graves, and M Landreman,
     "Stellarator optimization for good magnetic surfaces at finite β and toroidal current",
     *Physics of Plasmas*, **29**, 042505 (2021).
     `[journal version] <https://doi.org/10.1063/5.0080809>`__
     `[arXiv version] <https://arxiv.org/pdf/2111.15564>`__
   |

#. | A Giuliani, F Wechsung, M Landreman, G Stadler, and A Cerfon,
     "Direct computation of magnetic surfaces in Boozer coordinates and coil optimization for quasi-symmetry",
     *Journal of Plasma Physics*, **88**, 905880401 (2022).
     `[journal version] <https://doi.org/10.1017/S0022377822000563>`__
     `[arXiv version] <https://arxiv.org/pdf/2203.03753>`__
   |

#. | F Wechsung, A Giuliani, M Landreman, A Cerfon, and G Stadler,
     "Stochastic and a-posteriori optimization to mitigate coil manufacturing errors in stellarator design",
     *Plasma Physics and Controlled Fusion*, **64**, 105021 (2022).
     `[journal version] <https://doi.org/10.1088/1361-6587/ac89ee>`__
     `[arXiv version] <https://arxiv.org/pdf/2203.10164>`__
   |

#. | M Landreman, S Buller, and M Drevlak,
     "Optimization of quasisymmetric stellarators with self-consistent bootstrap current and energetic particle confinement",
     *Physics of Plasmas*, **29**, 082501 (2022).
     `[journal version] <https://doi.org/10.1063/5.0098166>`__
     `[arXiv version] <https://arxiv.org/pdf/2205.02914>`__
   |

#. | R Jorge, G G Plunk, M Drevlak, M Landreman, J-F Lobsien, K Camacho Mata, and P Helander,
     "A single-field-period quasi-isodynamic stellarator",
     *Journal of Plasma Physics* **88**, 175880504 (2022).
     `[journal version] <https://doi.org/10.1017/S0022377822000873>`__
     `[arXiv version] <https://arxiv.org/pdf/2205.05797>`__
   |

#. | A Kaptanoglu, T Qian, F Wechsung, and M Landreman,
     "Permanent magnet optimization for stellarators as sparse regression",
     *Physical Review Applied*, **18**, 044006 (2022).
     `[journal version] <http://dx.doi.org/10.1103/PhysRevApplied.18.044006>`__
     `[arXiv version] <https://arxiv.org/pdf/2207.08984>`__
   |

#. | E J Paul, A Bhattacharjee, M Landreman, D Alex, J L Velasco, and R Nies,
     "Energetic particle loss mechanisms in reactor-scale equilibria close to quasisymmetry",
     *Nuclear Fusion*, **62**, 126054 (2022).
     `[journal version] <http://dx.doi.org/10.1088/1741-4326/ac9b07>`__
     `[arXiv version] <https://arxiv.org/pdf/2208.02351>`__
   |

#. | A Kaptanoglu, R Conlin, and M Landreman,
     "Greedy permanent magnet optimization",
     *Nuclear Fusion*, **63**, 036016 (2023).
     `[journal version] <http://dx.doi.org/10.1088/1741-4326/acb4a9>`__
     `[arXiv version] <https://arxiv.org/pdf/2208.10620>`__
   |

#. | G T Roberg-Clark, P Xanthopoulos, and G G Plunk,
     "Reduction of electrostatic turbulence in a quasi-helically symmetric stellarator via critical gradient optimization",
     *Submitted* (2022).
     `[arXiv version] <https://arxiv.org/pdf/2210.16030>`__
   |

#. | A Goodman, K Camacho Mata, S A Henneberg, R Jorge, M Landreman, G Plunk, H Smith, R Mackenbach, and P Helander,
     "Constructing precisely quasi-isodynamic magnetic fields",
     *Submitted* (2022).
     `[arXiv version] <https://arxiv.org/pdf/2211.09829>`__
   |

#. | G T Roberg-Clark, G G Plunk, P Xanthopoulos, C Nuhrenberg, S A Henneberg, and H M Smith,
     "Critical gradient turbulence optimization toward a compact stellarator reactor concept",
     *Submitted* (2022).
     `[arXiv version] <https://arxiv.org/pdf/2301.06773>`__
   |

#. | R Jorge, W Dorland, P Kim, M Landreman, N R Mandell, G Merlo, and T Qian,
     "Direct Microstability Optimization of Stellarator Devices",
     *Submitted* (2023).
     `[arXiv version] <https://arxiv.org/pdf/2301.09356>`__
   |

#. | R Gaur, S Buller, M E Ruth, M Landreman, I G Abel, and W D Dorland,
     "An adjoint-based method for optimizing MHD equilibria against the infinite-n, ideal ballooning mode",
     *Submitted* (2023).
     `[arXiv version] <https://arxiv.org/pdf/2302.07673>`__
   |

#. | D Bindel, M Landreman, and M Padidar,
     "Direct Optimization of Fast-Ion Confinement in Stellarators",
     *Submitted* (2023).
     `[arXiv version] <https://arxiv.org/pdf/2302.11369>`__
   |

#. | R Jorge, A Goodman, M Landreman, J Rodrigues, F Wechsung,
     "Single-Stage Stellarator Optimization: Combining Coils with Fixed Boundary Equilibria",
     *Submitted* (2023).
     `[arXiv version] <https://arxiv.org/pdf/2302.10622>`__
   |

